@@ -1,4 +1,4 @@
-from automl_alex.base import ModelBase
+from automl_alex._base import ModelBase
 import catboost
 from catboost import Pool
 import numpy as np
@@ -32,9 +32,9 @@ class CatBoost(ModelBase):
         Args:
             params: : parameters for model.
         """
-        if self.type_of_estimator == 'classifier':
+        if self._type_of_estimator == 'classifier':
             model = catboost.CatBoostClassifier(**model_param)
-        elif self.type_of_estimator == 'regression':
+        elif self._type_of_estimator == 'regression':
             model = catboost.CatBoostRegressor(**model_param)
         return(model)
 
@@ -46,7 +46,7 @@ class CatBoost(ModelBase):
             y (pd.DataFrame, shape (n_samples, ) or (n_samples, n_outputs)): the target data
             cat_features (list)
         Return:
-            self (Class)
+            self
         """
         y_train = self.y_format(y_train)
 
@@ -73,9 +73,9 @@ class CatBoost(ModelBase):
         if self.model is None:
             raise Exception("No fit models")
 
-        if self.type_of_estimator == 'classifier':
+        if self._type_of_estimator == 'classifier':
             predicts = np.round(self.model.predict(X),0)
-        elif self.type_of_estimator == 'regression':
+        elif self._type_of_estimator == 'regression':
             predicts = self.model.predict(X)
         return predicts
 
@@ -131,34 +131,26 @@ class CatBoost(ModelBase):
         """
         model_param = self._init_default_model_param()
         ################################# LVL 1 ########################################
-        if opt_lvl == 1:
-            model_param['depth'] = trial.suggest_categorical('cb_depth', [6, 10])
-
         if opt_lvl >= 1:
             model_param['min_child_samples'] = trial.suggest_int('cb_min_child_samples', 1, 100)
+            model_param['depth'] = trial.suggest_int('cb_depth', 4, 10)
             
 
         ################################# LVL 2 ########################################
-        if opt_lvl == 2:
-            model_param['depth'] = trial.suggest_categorical('cb_depth', [4, 6, 10])
-
         if opt_lvl >= 2:
             model_param['bagging_temperature'] = trial.suggest_int('cb_bagging_temperature', 0, 10,)
             model_param['subsample'] = trial.suggest_discrete_uniform('cb_subsample', 0.1, 1.0, 0.1)
         
         ################################# LVL 3 ########################################
-        if opt_lvl == 3:
-            model_param['depth'] = trial.suggest_categorical('cb_depth', [4, 6, 8, 10])
-
         if opt_lvl >= 3:
-            if self.type_of_estimator == 'classifier':
+            if self._type_of_estimator == 'classifier':
                 model_param['objective'] = trial.suggest_categorical('cb_objective', 
                         [
                         'Logloss', 
                         'CrossEntropy',
                         ])
 
-            elif self.type_of_estimator == 'regression':
+            elif self._type_of_estimator == 'regression':
                 model_param['objective'] = trial.suggest_categorical('cb_objective', 
                     [
                     'MAE',
@@ -192,10 +184,10 @@ class CatBoost(ModelBase):
 
 
 class CatBoostClassifier(CatBoost):
-    type_of_estimator='classifier'
+    _type_of_estimator='classifier'
     __name__ = 'CatBoostClassifier'
 
 
 class CatBoostRegressor(CatBoost):
-    type_of_estimator='regression'
+    _type_of_estimator='regression'
     __name__ = 'CatBoostRegressor'
\ No newline at end of file
