@@ -1,4 +1,4 @@
-from automl_alex.base import ModelBase
+from automl_alex._base import ModelBase
 import lightgbm as lgb
 import numpy as np
 import pandas as pd
@@ -22,21 +22,21 @@ class LightGBM(ModelBase):
                             'device_type': 'gpu' if self._gpu else 'cpu',
                             }
         
-        if self.type_of_estimator == 'classifier':
+        if self._type_of_estimator == 'classifier':
             model_param['objective'] = 'binary'
         
-        if self.type_of_estimator == 'regression':
+        if self._type_of_estimator == 'regression':
             model_param['objective'] = 'regression'
         return(model_param)
 
 
-    def fit(self, X_train=None, y_train=None, cat_features=None):
+    def fit(self, X_train=None, y_train=None, cat_features=None) -> None:
         """
         Args:
             X (pd.DataFrame, shape (n_samples, n_features)): the input data
             y (pd.DataFrame, shape (n_samples, ) or (n_samples, n_outputs)): the target data
         Return:
-            self (Class)
+            self
         """
         y_train = self.y_format(y_train)
         
@@ -55,6 +55,7 @@ class LightGBM(ModelBase):
             categorical_feature=cat_features,
             )
         dtrain=None
+        return(self)
 
 
     def predict(self, X=None):
@@ -67,9 +68,9 @@ class LightGBM(ModelBase):
         if self.model is None:
             raise Exception("No fit models")
 
-        if self.type_of_estimator == 'classifier':
+        if self._type_of_estimator == 'classifier':
             predicts = np.round(self.model.predict(X),0)
-        elif self.type_of_estimator == 'regression':
+        elif self._type_of_estimator == 'regression':
             predicts = self.model.predict(X)
         return predicts
 
@@ -124,19 +125,16 @@ class LightGBM(ModelBase):
         """
         model_param = self._init_default_model_param()
         ################################# LVL 1 ########################################
-        if opt_lvl == 1:
-            model_param['num_leaves'] = trial.suggest_int('lgbm_num_leaves', 2, 50, log=True)
-            
         if opt_lvl >= 1:
-            model_param['min_child_samples'] = trial.suggest_int('lgbm_min_child_samples', 2, 100, log=True)
+            model_param['num_leaves'] = trial.suggest_int('lgbm_num_leaves', 2, 100, log=True)
+            model_param['learning_rate'] = trial.suggest_float('lgbm_learning_rate', 1e-2, 0.3, log=True)
 
         ################################# LVL 2 ########################################
         if opt_lvl == 2:
-            model_param['learning_rate'] = trial.suggest_float('lgbm_learning_rate', 1e-2, 0.3, log=True)
-            model_param['num_leaves'] = trial.suggest_int('lgbm_num_leaves', 2, 50, log=True)
             model_param['num_iterations'] = trial.suggest_int('lgbm_num_iterations', 300, 500, step=100)
 
         if opt_lvl >= 2:
+            model_param['min_child_samples'] = trial.suggest_int('lgbm_min_child_samples', 2, 100, log=True)
             model_param['bagging_fraction'] = trial.suggest_float('lgbm_bagging_fraction', 0.4, 1., step=0.1)
             if model_param['bagging_fraction'] < 1.:
                 model_param['feature_fraction'] = trial.suggest_float('lgbm_feature_fraction', 0.4, 1., step=0.1)
@@ -144,12 +142,8 @@ class LightGBM(ModelBase):
         
         ################################# LVL 3 ########################################
         if opt_lvl == 3:
-            model_param['learning_rate'] = trial.suggest_float('lgbm_learning_rate', 1e-2, 0.3, log=True)
             model_param['num_iterations'] = trial.suggest_int('lgbm_num_iterations', 300, 1000, step=100)
         
-        if opt_lvl >= 3:
-            model_param['num_leaves'] = trial.suggest_int('lgbm_num_leaves', 2, 100, log=True)
-        
         ################################# LVL 4 ########################################
         if opt_lvl == 4:
             model_param['learning_rate'] = trial.suggest_float('lgbm_learning_rate', 1e-3, .1, log=True)
@@ -166,14 +160,14 @@ class LightGBM(ModelBase):
 
             model_param['num_iterations'] = trial.suggest_int('lgbm_num_iterations', 200, 1500, step=100,)
 
-            if self.type_of_estimator == 'classifier':
+            if self._type_of_estimator == 'classifier':
                 model_param['objective'] = trial.suggest_categorical('lgbm_objective', 
                     [
                     'binary', 
                     'cross_entropy',
                     ])
 
-            elif self.type_of_estimator == 'regression':
+            elif self._type_of_estimator == 'regression':
                 model_param['objective'] = trial.suggest_categorical('lgbm_objective', 
                     [
                     'regression',
@@ -214,8 +208,8 @@ class LightGBM(ModelBase):
 
 
 class LightGBMClassifier(LightGBM):
-    type_of_estimator='classifier'
+    _type_of_estimator='classifier'
 
 
 class LightGBMRegressor(LightGBM):
-    type_of_estimator='regression'
\ No newline at end of file
+    _type_of_estimator='regression'
\ No newline at end of file
